@@ -23,8 +23,6 @@
 
 #include <QTextStream>
 
-#include <KQuickAddons/QtQuickSettings>
-
 #include <kworkspace.h>
 
 #include <iostream>
@@ -64,8 +62,6 @@ int main(int argc, char **argv)
         if (strcmp("--test", argv[i]) == 0 || strcmp("--help", argv[i]) == 0)
             test = true;
     }
-
-    KQuickAddons::QtQuickSettings::init();
     //enable to send log output to /tmp/ksplash
     //which is useful for debugging
 //     qInstallMsgHandler(myMessageHandler);
