@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2016 Harald Sitter <sitter@kde.org>
+ *   Copyright (C) 2016-2020 Harald Sitter <sitter@kde.org>
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -24,12 +24,16 @@
 #include <QObject>
 #include <QStandardPaths>
 #include <QTest>
+#include <QThread>
 
 #include <KSycoca>
 
 #include "../servicerunner.h"
 
 #include <clocale>
+#include <optional>
+#include <sys/types.h>
+#include <unistd.h>
 
 class ServiceRunnerTest : public QObject
 {
@@ -41,6 +45,8 @@ private Q_SLOTS:
     void testChromeAppsRelevance();
     void testKonsoleVsYakuakeComment();
     void testSystemSettings();
+    void testForeignAppsOutscoreKCMs();
+    void testINotifyUsage();
 };
 
 void ServiceRunnerTest::initTestCase()
@@ -51,7 +57,8 @@ void ServiceRunnerTest::initTestCase()
     QDir(appsPath).removeRecursively();
     QVERIFY(QDir().mkpath(appsPath));
     auto fixtureDir = QDir(QFINDTESTDATA("fixtures"));
-    for(auto fileInfo : fixtureDir.entryInfoList(QDir::Files)) {
+    const auto infoList = fixtureDir.entryInfoList(QDir::Files);
+    for (const auto &fileInfo : infoList) {
         auto source = fileInfo.absoluteFilePath();
         auto target = appsPath + QDir::separator() + fileInfo.fileName();
         QVERIFY2(QFile::copy(fileInfo.absoluteFilePath(), target),
@@ -82,7 +89,8 @@ void ServiceRunnerTest::testChromeAppsRelevance()
 
     bool chromeFound = false;
     bool signalFound = false;
-    for (auto match : context.matches()) {
+    const auto matches = context.matches();
+    for (const auto &match : matches) {
         qDebug() << "matched" << match.text();
         if (!match.text().contains(QLatin1String("ServiceRunnerTest"))) {
             continue;
@@ -112,7 +120,8 @@ void ServiceRunnerTest::testKonsoleVsYakuakeComment()
 
     bool konsoleFound = false;
     bool yakuakeFound = false;
-    for (auto match : context.matches()) {
+    const auto matches = context.matches();
+    for (const auto &match : matches) {
         qDebug() << "matched" << match.text();
         if (!match.text().contains(QLatin1String("ServiceRunnerTest"))) {
             continue;
@@ -146,7 +155,8 @@ void ServiceRunnerTest::testSystemSettings()
 
     bool systemSettingsFound = false;
     bool foreignSystemSettingsFound = false;
-    for (auto match : context.matches()) {
+    const auto matches = context.matches();
+    for (const auto &match : matches) {
         qDebug() << "matched" << match.text();
         if (match.text() == QLatin1String("System Settings ServiceRunnerTest")) {
             systemSettingsFound = true;
@@ -159,6 +169,80 @@ void ServiceRunnerTest::testSystemSettings()
     QVERIFY(!foreignSystemSettingsFound);
 }
 
+void ServiceRunnerTest::testForeignAppsOutscoreKCMs()
+{
+    // Our software outscores other things, but foreign applications should still
+    // outscore our KCMs.
+    ServiceRunner runner(this, QVariantList());
+    Plasma::RunnerContext context;
+    context.setQuery(QStringLiteral("virt"));
+
+    runner.match(context);
+
+    std::optional<qreal> virtManRelevance;
+    std::optional<qreal> virtThingsRelevance;
+    std::optional<qreal> kcmRelevance;
+    const auto matches = context.matches();
+    for (const auto &match : matches) {
+        const QUrl url = match.data().toUrl();
+        if (url == QUrl(QStringLiteral("applications:virt-manager.desktop"))) {
+            virtManRelevance = match.relevance();
+        } else if (url == QUrl(QStringLiteral("applications:kcm_kwin_virtualdesktops.desktop"))) {
+            kcmRelevance = match.relevance();
+        } else if (url == QUrl(QStringLiteral("applications:org.kde.virtthings.desktop"))) {
+            virtThingsRelevance = match.relevance();
+        }
+    }
+    QVERIFY(virtManRelevance.has_value());
+    QVERIFY(virtThingsRelevance.has_value());
+    QVERIFY(kcmRelevance.has_value());
+
+    // KDE app should be >= non-KDE app
+    QVERIFY2(virtThingsRelevance >= virtManRelevance,
+             qPrintable(QStringLiteral("%1 >= %2").arg(virtThingsRelevance.value()).arg(virtManRelevance.value())));
+    // KDE app strictly greater KDE kcm
+    QVERIFY2(virtThingsRelevance > kcmRelevance,
+             qPrintable(QStringLiteral("%1 > %2").arg(virtThingsRelevance.value()).arg(kcmRelevance.value())));
+    // non-KDE app also strictly greater (because it is an app)
+    QVERIFY2(virtManRelevance > kcmRelevance,
+             qPrintable(QStringLiteral("%1 > %2").arg(virtManRelevance.value()).arg(kcmRelevance.value())));
+}
+
+void ServiceRunnerTest::testINotifyUsage()
+{
+    auto inotifyCount = []() -> uint {
+        uint count = 0;
+        const QDir procDir(QStringLiteral("/proc/%1/fd").arg(getpid()));
+        for (const auto &fileInfo : procDir.entryInfoList()) {
+            if (fileInfo.symLinkTarget().endsWith(QStringLiteral("anon_inode:inotify"))) {
+                ++count;
+            }
+        }
+        return count;
+    };
+
+    const uint originalCount = inotifyCount();
+
+    // We'll run this in a new thread so KDirWatch would be led to create a new thread-local watch instance.
+    // The expectation here is that this KDW instance is not persistently claiming an inotify instance.
+    bool inotifyCountCool = false;
+    auto thread = QThread::create([&] {
+        ServiceRunner runner(nullptr, QVariantList());
+        Plasma::RunnerContext context;
+        context.setQuery(QStringLiteral("settings"));
+
+        runner.match(context);
+
+        QCOMPARE(inotifyCount(), originalCount);
+        inotifyCountCool = true;
+    });
+    thread->start();
+    thread->wait();
+    thread->deleteLater();
+
+    QVERIFY(inotifyCountCool);
+}
+
 QTEST_MAIN(ServiceRunnerTest)
 
 #include "servicerunnertest.moc"
