@@ -24,10 +24,6 @@ int main(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
 
-    // This is needed with KJobs in a QCoreApplication as when they finish
-    // the internal QEventLoopLocker expires and our app exits
-    app.setQuitLockEnabled(false);
-
     new Startup(&app);
     app.exec();
 }
